@@ -23,7 +23,7 @@
 #if !defined(__gda_table_h__)
 #  define __gda_table_h__
 
-#include <libgda/gda-recordset.h>
+#include <libgda/gda-data-model-array.h>
 #include <libgda/gda-row.h>
 
 G_BEGIN_DECLS
@@ -45,16 +45,22 @@ struct _GdaTable {
 
 struct _GdaTableClass {
 	GdaDataModelArrayClass parent_class;
+
+	/* signals */
+	void (* name_changed) (GdaTable *table, const gchar *old_name);
 };
 
-GType     gda_table_get_type (void);
-GdaTable *gda_table_new (const gchar *name);
-GdaTable *gda_table_new_from_model (const gchar *name,
-				    const GdaDataModel *model,
-				    gboolean add_data);
+GType        gda_table_get_type (void);
+GdaTable    *gda_table_new (const gchar *name);
+GdaTable    *gda_table_new_from_model (const gchar *name,
+				       const GdaDataModel *model,
+				       gboolean add_data);
 
-void      gda_table_add_field (GdaTable *table, const GdaFieldAttributes *fa);
-void      gda_table_add_data_from_model (GdaTable *table, const GdaDataModel *model);
+const gchar *gda_table_get_name (GdaTable *table);
+void         gda_table_set_name (GdaTable *table, const gchar *name);
+
+void         gda_table_add_field (GdaTable *table, const GdaFieldAttributes *fa);
+void         gda_table_add_data_from_model (GdaTable *table, const GdaDataModel *model);
 
 G_END_DECLS
 
