@@ -1,5 +1,5 @@
 /* GDA MySQL provider
- * Copyright (C) 1998-2002 The GNOME Foundation.
+ * Copyright (C) 1998-2004 The GNOME Foundation.
  *
  * AUTHORS:
  *      Michael Lausch <michael@lausch.at>
@@ -83,7 +83,11 @@ static GdaDataModel *gda_mysql_provider_get_schema (GdaServerProvider *provider,
 						    GdaConnection *cnc,
 						    GdaConnectionSchema schema,
 						    GdaParameterList *params);
-
+static gboolean gda_mysql_provider_escape_string (GdaServerProvider *provider,
+						  GdaConnection *cnc,
+						  const gchar *from,
+						  gchar *to);
+				 		 
 static GObjectClass *parent_class = NULL;
 
 /*
@@ -114,6 +118,7 @@ gda_mysql_provider_class_init (GdaMysqlProviderClass *klass)
 	provider_class->rollback_transaction = gda_mysql_provider_rollback_transaction;
 	provider_class->supports = gda_mysql_provider_supports;
 	provider_class->get_schema = gda_mysql_provider_get_schema;
+	provider_class->escape_string = gda_mysql_provider_escape_string;
 }
 
 static void
@@ -171,7 +176,7 @@ gda_mysql_provider_get_version (GdaServerProvider *provider)
 
 	g_return_val_if_fail (GDA_IS_MYSQL_PROVIDER (myprv), NULL);
 
-	return VERSION;
+	return PACKAGE_VERSION;
 }
 
 /* open_connection handler for the GdaMysqlProvider class */
@@ -209,9 +214,9 @@ gda_mysql_provider_open_connection (GdaServerProvider *provider,
 	t_unix_socket = gda_quark_list_find (params, "UNIX_SOCKET");
 	t_use_ssl = gda_quark_list_find (params, "USE_SSL");
 
-	if (username)
+	if (username && *username != '\0')
 		t_user = username;
-	if (password)
+	if (password && *password != '\0')
 		t_password = password;
 
 	if (t_use_ssl && atoi (t_use_ssl) == 1)
@@ -514,7 +519,7 @@ gda_mysql_provider_execute_command (GdaServerProvider *provider,
 
 		g_free (str);
 		break;
-	default: ;
+	default: break;
 	}
 
 	return reclist;
@@ -538,7 +543,7 @@ gda_mysql_provider_get_last_insert_id (GdaServerProvider *provider,
 		return NULL;
 	}
 
-	return g_strdup_printf ("%ul", mysql_insert_id (mysql));
+	return g_strdup_printf ("%ld", (unsigned long int ) mysql_insert_id (mysql));
 }
 
 /* begin_transaction handler for the GdaMysqlProvider class */
@@ -680,7 +685,7 @@ gda_mysql_provider_supports (GdaServerProvider *provider,
 	case GDA_CONNECTION_FEATURE_SQL :
 	case GDA_CONNECTION_FEATURE_TRANSACTIONS :
 		return TRUE;
-	default : ;
+	default : break;
 	}
 
 	return FALSE;
@@ -710,7 +715,7 @@ add_aggregate_row (GdaDataModelArray *recset, const gchar *str, const gchar *com
 
 	gda_data_model_append_row (GDA_DATA_MODEL (recset), list);
 
-	g_list_foreach (list, gda_value_free, NULL);
+	g_list_foreach (list, (GFunc) gda_value_free, NULL);
 	g_list_free (list);
 }
 
@@ -971,21 +976,31 @@ get_mysql_types (GdaConnection *cnc, GdaParameterList *params)
 		GdaValueType type;
 	} types[] = {
 		{ "blob", "", "Binary blob", GDA_VALUE_TYPE_BINARY },
+		{ "bigint", "", "Big integer", GDA_VALUE_TYPE_BIGINT },
+		{ "char", "", "Char", GDA_VALUE_TYPE_STRING },
 		{ "date", "", "Date", GDA_VALUE_TYPE_DATE },
 		{ "datetime", "", "Date and time", GDA_VALUE_TYPE_TIMESTAMP },
 		{ "decimal", "", "Decimal number", GDA_VALUE_TYPE_DOUBLE },
 		{ "double", "", "Double precision number", GDA_VALUE_TYPE_DOUBLE },
 		{ "enum", "", "Enumeration", GDA_VALUE_TYPE_STRING },
 		{ "float", "", "Single precision number", GDA_VALUE_TYPE_SINGLE },
-		{ "int24", "", "24 bit integer", GDA_VALUE_TYPE_BIGINT },
+		{ "int", "", "Integer", GDA_VALUE_TYPE_INTEGER },
+		{ "integer", "", "Integer", GDA_VALUE_TYPE_INTEGER },		
 		{ "long", "", "Long integer", GDA_VALUE_TYPE_INTEGER },
-		{ "longlong", "", "Extra long integer", GDA_VALUE_TYPE_BIGINT },
+		{ "longblob", "", "Long blob", GDA_VALUE_TYPE_BINARY },
+		{ "longtext", "", "Long text", GDA_VALUE_TYPE_STRING },
+		{ "mediumint", "", "Medium integer", GDA_VALUE_TYPE_INTEGER },
+		{ "mediumblob", "", "Medium blob", GDA_VALUE_TYPE_BINARY },
+		{ "mediumtext", "", "Medium text", GDA_VALUE_TYPE_STRING },				
 		{ "set", "", "Set", GDA_VALUE_TYPE_STRING },
-		{ "short", "", "Short integer", GDA_VALUE_TYPE_SMALLINT },
-		{ "string", "", "String", GDA_VALUE_TYPE_STRING },
+		{ "smallint", "", "Small integer", GDA_VALUE_TYPE_INTEGER },
+		{ "text", "", "Text", GDA_VALUE_TYPE_STRING },
+		{ "tinyint", "", "Tiny integer", GDA_VALUE_TYPE_INTEGER }, /* really a boolean */
+		{ "tinyblob", "", "Tiny blob", GDA_VALUE_TYPE_BINARY },
+		{ "tinytext", "", "Tiny text", GDA_VALUE_TYPE_STRING },		
 		{ "time", "", "Time", GDA_VALUE_TYPE_TIME },
 		{ "timestamp", "", "Time stamp", GDA_VALUE_TYPE_TIMESTAMP },
-		{ "tiny", "", "Tiny integer", GDA_VALUE_TYPE_SMALLINT },
+		{ "varchar", "", "Variable Length Char", GDA_VALUE_TYPE_STRING },
 		{ "year", "", "Year", GDA_VALUE_TYPE_INTEGER }
 	};
 
@@ -1211,8 +1226,31 @@ gda_mysql_provider_get_schema (GdaServerProvider *provider,
 		return get_mysql_tables (cnc, params);
 	case GDA_CONNECTION_SCHEMA_TYPES :
 		return get_mysql_types (cnc, params);
-	default : ;
+	default : break;
 	}
 
 	return NULL;
 }
+
+
+gboolean
+gda_mysql_provider_escape_string (GdaServerProvider *provider,
+				  GdaConnection *cnc,
+				  const gchar *from,
+				  gchar *to)
+{
+	MYSQL *mysql;
+	GdaMysqlProvider *myprv = (GdaMysqlProvider *) provider;
+
+	g_return_val_if_fail (GDA_IS_MYSQL_PROVIDER (myprv), FALSE);
+	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
+	g_return_val_if_fail (from != NULL, FALSE);
+	g_return_val_if_fail (to != NULL, FALSE);
+
+	mysql = g_object_get_data (G_OBJECT (cnc), OBJECT_DATA_MYSQL_HANDLE);
+	if (!mysql) {
+		gda_connection_add_error_string (cnc, _("Invalid MYSQL handle"));
+		return 0;
+	}
+	return mysql_real_escape_string (mysql, to, from, strlen (from));
+}
